@@ -10,6 +10,7 @@ Copyright (c) 2012 Multmeio [design+tecnologia]. All rights reserved.
 from django import forms
 from django.db import models
 from django.utils.text import capfirst
+from django.core.cache import cache
 from decimal import Decimal, InvalidOperation
 from datetime import date, datetime
 
@@ -17,6 +18,10 @@ from hstore_flattenfields.utils import *
 from hstore_flattenfields.forms.fields import *
 from hstore_flattenfields.models import DynamicField
 
+def get_dynamic_from_cache(name):
+    return [f for f in cache.get('dynamic_fields', []) \
+            if f.name == name][0]
+
 
 class HstoreTextField(models.TextField):
     __metaclass__ = models.SubfieldBase
@@ -139,8 +144,7 @@ class HstoreCharField(models.CharField):
         # FIXME: this maybe mistake on fields with same name in different
         # refers
         try:
-            dynamic_field = DynamicField.objects.find_dfields(
-                name=self.name)[0]
+            dynamic_field = get_dynamic_from_cache(self.name)
             if dynamic_field.has_blank_option:
                 choices = super(HstoreMultipleSelectField, self).get_choices()
         except IndexError:
@@ -210,12 +214,12 @@ class HstoreDateField(models.DateField):
         return form_class(**defaults)
 
     def to_python(self, value):
-        if not value or value is models.fields.NOT_PROVIDED or value == 'None':
+        if not value or value is models.fields.NOT_PROVIDED:
             return None
         return str2date(value)
 
     def clean(self, value, *args):
-        if value == 'None' or not value:
+        if not value:
             return ''
         return value
 
@@ -251,12 +255,12 @@ class HstoreDateTimeField(models.DateTimeField):
         return form_class(**defaults)
 
     def to_python(self, value):
-        if not value or value is models.fields.NOT_PROVIDED or value == 'None':
+        if not value or value is models.fields.NOT_PROVIDED:
             return None
         return str2datetime(value)
 
     def clean(self, value, *args):
-        if value == 'None' or not value:
+        if not value:
             return ''
         return value
 
@@ -284,7 +288,7 @@ class HstoreSelectField(models.CharField):
     def clean(self, value, *args):
         # FIXME: At the beginning of the project there was
         #       a bug that was saving the value as a string: 'None'
-        if value == 'None' or not value:
+        if not value:
             return ''
         return value
 
@@ -354,8 +358,7 @@ class HstoreRadioSelectField(models.CharField):
         # FIXME: this maybe mistake on fields with same name in different
         # refers
         try:
-            dynamic_field = DynamicField.objects.find_dfields(
-                name=self.name)[0]
+            dynamic_field = get_dynamic_from_cache(self.name)
             if dynamic_field.has_blank_option:
                 choices = super(HstoreRadioSelectField, self).get_choices()
         except IndexError:
@@ -429,8 +432,7 @@ class HstoreCheckboxField(models.CharField):
         # FIXME: this maybe mistake on fields with same name in different
         # refers
         try:
-            dynamic_field = DynamicField.objects.find_dfields(
-                name=self.name)[0]
+            dynamic_field = get_dynamic_from_cache(self.name)
             if dynamic_field.has_blank_option:
                 choices = super(HstoreCheckboxField, self).get_choices()
         except IndexError:
@@ -512,8 +514,7 @@ class HstoreMultipleSelectField(models.CharField):
         # FIXME: this maybe mistake on fields with same name in different
         # refers
         try:
-            dynamic_field = DynamicField.objects.find_dfields(
-                name=self.name)[0]
+            dynamic_field = get_dynamic_from_cache(self.name)
             if dynamic_field.has_blank_option:
                 choices = super(HstoreMultipleSelectField, self).get_choices()
         except IndexError:
