@@ -8,16 +8,17 @@ when you run "manage.py test".
 Replace this with more appropriate tests for your application.
 """
 
-from django.test import TestCase, skipUnlessDBFeature
+# from django.test import TestCase, skipUnlessDBFeature
 from django.core.exceptions import FieldError, ValidationError
 from django.db.models import Sum
 from datetime import date, datetime
 from decimal import Decimal
 from operator import attrgetter
 
-from tests.app.models import *
-# from hstore_flattenfields.models import DynamicField
 from hstore_flattenfields.db.aggregates import *
+from hstore_flattenfields.db.cache import TestCase
+
+from tests.app.models import *
 
 
 # class NameCollisionTests(TestCase):
@@ -50,6 +51,8 @@ class IntegrityTests(TestCase):
 
 
 class LookupTests(TestCase):
+    maxDiff = None
+
     def setUp(self):
         # Create a few DynamicFields.
         DynamicField.objects.create(refer="Author", name="author_name", verbose_name=u"Name", typo="CharField", max_length=100)
